package com.bonus.canteen.core.basic.mapper;

import java.util.List;
import com.bonus.canteen.core.basic.domain.BasicStallMealtime;
import org.apache.ibatis.annotations.Param;

/**
 * 档口餐次配置Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface BasicStallMealtimeMapper {
    /**
     * 查询档口餐次配置
     * 
     * @param id 档口餐次配置主键
     * @return 档口餐次配置
     */
    public BasicStallMealtime selectBasicStallMealtimeById(Long id);

    /**
     * 查询档口餐次配置列表
     * 
     * @param basicStallMealtime 档口餐次配置
     * @return 档口餐次配置集合
     */
    public List<BasicStallMealtime> selectBasicStallMealtimeList(BasicStallMealtime basicStallMealtime);

    /**
     * 新增档口餐次配置
     * 
     * @param basicStallMealtime 档口餐次配置
     * @return 结果
     */
    public int insertBasicStallMealtime(BasicStallMealtime basicStallMealtime);

    public int batchInsertBasicStallMealtime(@Param("list") List<BasicStallMealtime> allocStallMealtimes);

    /**
     * 修改档口餐次配置
     * 
     * @param basicStallMealtime 档口餐次配置
     * @return 结果
     */
    public int updateBasicStallMealtime(BasicStallMealtime basicStallMealtime);

    /**
     * 删除档口餐次配置
     * 
     * @param id 档口餐次配置主键
     * @return 结果
     */
    public int deleteBasicStallMealtimeById(Long id);

    /**
     * 批量删除档口餐次配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasicStallMealtimeByIds(Long[] ids);

    public int deleteBasicStallMealtimeByStallId(Long stallId);
}
