package com.bonus.canteen.core.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.basic.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.basic.domain.BasicStallMealtime;
import com.bonus.canteen.core.basic.service.IBasicStallMealtimeService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 档口餐次配置Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "档口餐次配置接口")
@RestController
@RequestMapping("/basic_stall_mealtime")
public class BasicStallMealtimeController extends BaseController {
    @Autowired
    private IBasicStallMealtimeService basicStallMealtimeService;

    /**
     * 查询档口餐次配置列表
     */
    @ApiOperation(value = "查询档口餐次配置列表")
    //@RequiresPermissions("basic:mealtime:list")
    @GetMapping("/list")
    public TableDataInfo list(BasicStallMealtime basicStallMealtime) {
        startPage();
        List<BasicStallMealtime> list = basicStallMealtimeService.selectBasicStallMealtimeList(basicStallMealtime);
        return getDataTable(list);
    }

    /**
     * 导出档口餐次配置列表
     */
    @ApiOperation(value = "导出档口餐次配置列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:mealtime:export")
    @SysLog(title = "档口餐次配置", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出档口餐次配置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicStallMealtime basicStallMealtime) {
        List<BasicStallMealtime> list = basicStallMealtimeService.selectBasicStallMealtimeList(basicStallMealtime);
        ExcelUtil<BasicStallMealtime> util = new ExcelUtil<BasicStallMealtime>(BasicStallMealtime.class);
        util.exportExcel(response, list, "档口餐次配置数据");
    }

    /**
     * 获取档口餐次配置详细信息
     */
    @ApiOperation(value = "获取档口餐次配置详细信息")
    //@RequiresPermissions("basic:mealtime:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(basicStallMealtimeService.selectBasicStallMealtimeById(id));
    }

    /**
     * 新增档口餐次配置
     */
    @ApiOperation(value = "新增档口餐次配置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:mealtime:add")
    @SysLog(title = "档口餐次配置", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增档口餐次配置")
    @PostMapping
    public AjaxResult add(@RequestBody BasicStallMealtime basicStallMealtime) {
        try {
            return toAjax(basicStallMealtimeService.insertBasicStallMealtime(basicStallMealtime));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改档口餐次配置
     */
    @ApiOperation(value = "修改档口餐次配置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:mealtime:edit")
    @SysLog(title = "档口餐次配置", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改档口餐次配置")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BasicStallMealtime basicStallMealtime) {
        try {
            return toAjax(basicStallMealtimeService.updateBasicStallMealtime(basicStallMealtime));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除档口餐次配置
     */
    @ApiOperation(value = "删除档口餐次配置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:mealtime:remove")
    @SysLog(title = "档口餐次配置", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除档口餐次配置")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(basicStallMealtimeService.deleteBasicStallMealtimeByIds(ids));
    }
}
